@@ -233,7 +233,6 @@ class BaseStl(base.BaseMesh):
         else:
             iterator = cls._ascii_reader(fh, header)
             name = next(iterator)
-            print('got name', name)
             return name, numpy.fromiter(iterator, dtype=cls.dtype)
 
     def save(self, filename, fh=None, mode=AUTOMATIC, update_normals=True):
@@ -379,7 +378,7 @@ class BaseStl(base.BaseMesh):
 
     @classmethod
     def from_multi_file(cls, filename, calculate_normals=True, fh=None,
-                        mode=Mode.ASCII, speedups=True, **kwargs):
+                        mode=Mode.AUTOMATIC, speedups=True, **kwargs):
         '''Load multiple meshes from a STL file
 
         Note: mode is hardcoded to ascii since binary stl files do not support
